@@ -32,7 +32,9 @@ namespace citygml {
             GT_Closure          = 1 << 4,
             GT_Floor            = 1 << 5,
             GT_InteriorWall     = 1 << 6,
-            GT_Ceiling          = 1 << 7
+            GT_Ceiling          = 1 << 7,
+            GT_OuterCeiling     = 1 << 8,
+            GT_OuterFloor       = 1 << 9
         };
 
         unsigned int getLOD() const;
@@ -80,10 +82,10 @@ namespace citygml {
 
         unsigned int m_lod;
 
-        std::vector<std::shared_ptr<Geometry>> m_childGeometries;
+        std::vector<std::shared_ptr<Geometry> > m_childGeometries;
 
-        std::vector<std::shared_ptr<Polygon>> m_polygons;
-        std::vector<std::shared_ptr<LineString>> m_lineStrings;
+        std::vector<std::shared_ptr<Polygon> > m_polygons;
+        std::vector<std::shared_ptr<LineString> > m_lineStrings;
     };
 
     std::ostream& operator<<( std::ostream& os, const citygml::Geometry& s );
