@@ -5,10 +5,10 @@
 #include "parser/citymodelelementparser.h"
 #include "parser/geocoordinatetransformer.h"
 
-#include "citygml/citygmllogger.h"
-#include "citygml/citygmlfactory.h"
-#include "citygml/citymodel.h"
-#include "citygml/tesselator.h"
+#include <citygml/citygmllogger.h>
+#include <citygml/citygmlfactory.h>
+#include <citygml/citymodel.h>
+#include <citygml/tesselator.h>
 
 #include <stdexcept>
 
@@ -133,6 +133,7 @@ namespace citygml {
                     CITYGML_LOG_INFO(m_logger, "Finished coordinates transformation .");
                 } catch (const std::runtime_error& e) {
                     CITYGML_LOG_ERROR(m_logger, "Coordinate transformation aborted: " << e.what());
+                    throw e;
                 }
             }
 
